NLSL: nlsdim.f90 File Reference

NLSL

- Main Page
- Modules
- Data Types List
- Files

- File List
- File Members

Modules | Variables
nlsdim.f90 File Reference

Go to the source code of this file.

## Modules
module | nlsdim

## Variables
integer, parameter | nlsdim::mxstep =2000
integer, parameter | nlsdim::mxdim =45000
integer, parameter | nlsdim::mxdim1 =MXDIM+1
integer, parameter | nlsdim::mxel =50000000
integer, parameter | nlsdim::mxspc =4
integer, parameter | nlsdim::mxcmt =16
integer, parameter | nlsdim::mxspt =512
integer, parameter | nlsdim::mxpt =MXSPT*MXSPC
integer, parameter | nlsdim::mxvar =10
integer, parameter | nlsdim::mxinp =4096
integer, parameter | nlsdim::mxsite =3
integer, parameter | nlsdim::mxsph =4
integer, parameter | nlsdim::mxfile =4
integer, parameter | nlsdim::mxtdg =MXSTEP*MXSITE*MXSPC
integer, parameter | nlsdim::mxtdm =MXSPC*MXSITE
integer, parameter | nlsdim::mxjcol =MXVAR+MXSITE
integer, parameter | nlsdim::mxtv =MXJCOL+4*MXSITE
integer, parameter | nlsdim::mxmts =13
integer, parameter | nlsdim::nfprm =43
integer, parameter | nlsdim::nvprm =35
integer, parameter | nlsdim::niprm =24
integer, parameter | nlsdim::nalias =12
integer, parameter | nlsdim::nsymtr =3
integer, parameter | nlsdim::nsymbl =5